diff --git a/configure.ac b/configure.ac
index 144bf78..a83e1eb 100644
--- a/configure.ac
+++ b/configure.ac
@@ -121,7 +121,6 @@ PKG_CHECK_MODULES(DISPLAY_PANEL, $COMMON_MODULES cinnamon-desktop x11)
 PKG_CHECK_MODULES(MEDIA_PANEL, $COMMON_MODULES)
 
 PKG_CHECK_MODULES(NETWORK_PANEL, $COMMON_MODULES gmodule-2.0)
-PKG_CHECK_MODULES(COLOR_PANEL, $COMMON_MODULES colord >= 0.1.14)
 PKG_CHECK_MODULES(REGION_PANEL, $COMMON_MODULES libgnomekbd >= 2.91.91
                   polkit-gobject-1 >= $POLKIT_REQUIRED_VERSION
                   libxklavier >= 5.1 libgnomekbdui >= 2.91.91)
@@ -197,15 +196,51 @@ if test x"$enable_cups" != x"no" ; then
   AC_SUBST(CUPS_LIBS)
 fi
 
+build_color=false
+AC_ARG_ENABLE(color,
+       AC_HELP_STRING([--disable-color],
+               [disable color management panel]),
+       [case "${enableval}" in
+               yes) WANT_COLOR=yes ;;
+               no) WANT_COLOR=no ;;
+               *) AC_MSG_ERROR(bad value ${enableval} for --disable-color) ;;
+       esac],
+       [WANT_COLOR=yes]) dnl Default value
+
+if test x$WANT_COLOR = xyes; then
+       PKG_CHECK_MODULES(COLOR_PANEL, $COMMON_MODULES colord >= 0.1.14)
+       build_color=true
+fi
+if test "x$build_color" = xtrue ; then
+       AC_DEFINE(BUILD_COLOR, 1, [Define to 1 to build the Color panel])
+fi
+AM_CONDITIONAL(BUILD_COLOR, test "x$build_color" = "xtrue")
+AC_SUBST(COLOR_PANEL_CFLAGS)
+AC_SUBST(COLOR_PANEL_LIBS)
+
 build_wacom=false
-PKG_CHECK_MODULES(WACOM_PANEL, [$COMMON_MODULES
+AC_ARG_ENABLE(wacom,
+       AC_HELP_STRING([--disable-wacom],
+               [disable wacom management panel]),
+       [case "${enableval}" in
+               yes) WANT_WACOM=yes ;;
+               no) WANT_WACOM=no ;;
+               *) AC_MSG_ERROR(bad value ${enableval} for --disable-wacom) ;;
+       esac],
+       [WANT_WACOM=yes]) dnl Default value
+
+if test x$WANT_WACOM = xyes; then
+        PKG_CHECK_MODULES(WACOM_PANEL, [$COMMON_MODULES
                   cinnamon-settings-daemon >= $CSD_REQUIRED_VERSION
                   xi >= 1.2 x11 libwacom >= $LIBWACOM_REQUIRED_VERSION
                   cinnamon-desktop
-                  gtk+-3.0 >= 3.8.0],
-                  [build_wacom="true" AC_DEFINE(HAVE_WACOM, 1, [Define if wacom is being build])], [build_wacom="false"])
-
+                  gtk+-3.0 >= 3.8.0])
+        build_wacom="true"
+        AC_DEFINE(HAVE_WACOM, 1, [Define if wacom is being build])]
+fi
 AM_CONDITIONAL(BUILD_WACOM, test "x$build_wacom" = "xtrue")
+AC_SUBST(WACOM_PANEL_CFLAGS)
+AC_SUBST(WACOM_PANEL_LIBS)
 
 # This is a hard-dependency for the region and user-accounts panels
 PKG_CHECK_MODULES(ISOCODES, iso-codes)
@@ -408,6 +443,13 @@ fi
 #else
 #	AC_MSG_NOTICE([   Using ConsoleKit for session tracking])
 #fi
+
+if test "x$build_color" = "xtrue"; then
+	AC_MSG_NOTICE([** Colord support (Color management panel)])
+else
+	AC_MSG_NOTICE([   Colord support disabled])
+fi
+
 if test "x$build_wacom" = "xtrue"; then
 	AC_MSG_NOTICE([** Wacom support (Wacom panel)])
 else
diff --git a/panels/Makefile.am b/panels/Makefile.am
index 76fbc88..466c2c6 100644
--- a/panels/Makefile.am
+++ b/panels/Makefile.am
@@ -18,6 +18,12 @@ else
 disabled_panels += network
 endif
 
+if BUILD_COLOR
+enabled_panels += color
+else
+disabled_panels += color
+endif
+
 if BUILD_WACOM
 enabled_panels += wacom
 else
